@@ -1,19 +1,20 @@
 #' Import the scenario spreadsheet
 #'
-#' This is a wrapper function around \code{\link{import_scenarios}} and
-#'   \code{\link{import_capabilities}}. When invoked, the output of both functions
-#'   are written to disk.
+#' This is a convenience wrapper around the \code{\link{import_scenarios}} and
+#'   \code{\link{import_capabilities}} functions. Writes cleaned
+#'   comma-separated formatted files for the scenarios and
+#'   capabilities to disk.
 #'
 #' @importFrom dplyr %>%
 #' @importFrom readr write_csv
 #' @importFrom utils data
 #' @importFrom tibble as_tibble rownames_to_column
-#' @param survey_file Path to survey XLSX file. Defaults to an Evaluator-provided sample spreadsheet.
+#' @param survey_file Path to survey Excel file. Defaults to an Evaluator-provided sample spreadsheet.
 #' @param domains Dataframe of domains and domain IDs. Defaults to built-in sample \code{domains} dataset.
-#' @param output_dir Output file directory. Defaults to a \code{data}
-#'   subdirectory in the current working directory.
+#' @param output_dir Output file directory.
+#'
 #' @export
-#' @return Dataframe of generated files (capabilities.csv and scenarios.csv)
+#' @return Dataframe of file information on the two newly created files.
 import_spreadsheet <- function(survey_file = system.file("survey",
                                                          "survey.xlsx",
                                                          package = "evaluator"),
@@ -22,12 +23,8 @@ import_spreadsheet <- function(survey_file = system.file("survey",
 
   ## ----survey_sheet--------------------------------------------------------
   #message("Target file is ", survey_file)
-
-  # use default domains if none supplied
-  domains <- if (is.null(domains)) {
-    utils::data(domains, package = "evaluator", envir = environment())
-    domains
-  } else {domains}
+  if (!dir.exists(output_dir)) {
+    stop("Non existant output directory specified - ", output_dir)}
 
   qualitative_scenarios <- import_scenarios(survey_file = survey_file,
                                             domains = domains)
@@ -35,7 +32,6 @@ import_spreadsheet <- function(survey_file = system.file("survey",
                                       domains = domains)
 
   ## ----write_files---------------------------------------------------------
-  if (!dir.exists(output_dir)) dir.create(output_dir)
   readr::write_csv(capabilities, path = file.path(output_dir, "capabilities.csv"))
   readr::write_csv(qualitative_scenarios, path =
                      file.path(output_dir, "qualitative_scenarios.csv"))
@@ -47,30 +43,46 @@ import_spreadsheet <- function(survey_file = system.file("survey",
 
 #' Import scenarios from survey spreadsheet
 #'
-#' @importFrom dplyr funs select mutate mutate_at
+#' @importFrom dplyr select mutate mutate_at arrange
 #' @importFrom rlang .data
 #' @importFrom utils data
 #' @importFrom purrr map
 #' @importFrom tidyr unnest
 #' @importFrom readxl read_excel
-#' @param survey_file Path to survey XLSX file. Defaults to a sample file if not supplied.
+#' @param survey_file Path to survey Excel file. Defaults to a sample file if not supplied.
 #' @param domains Dataframe of domains and domain IDs.
+#'
 #' @export
 #' @return Extracted qualitative scenarios as a dataframe.
 #' @examples
-#' data(domains)
-#' import_scenarios(domains = domains)
-import_scenarios <- function(survey_file = system.file("survey",
-                                                       "survey.xlsx",
-                                                       package = "evaluator"),
-                               domains) {
+#' data(mc_domains)
+#' import_scenarios(domains = mc_domains)
+import_scenarios <- function(survey_file = NULL, domains = NULL) {
+
+  survey_file <- if (is.null(survey_file)) {
+    system.file("survey", "survey.xlsx", package = "evaluator")
+  } else {
+    survey_file
+  }
+  if (!file.exists(survey_file)) {
+    stop("Non existant survey file specified - ", survey_file)}
+
+  # use default domains if none supplied
+  domains <- if (is.null(domains)) {
+    env <- new.env()
+    utils::data("mc_domains", package = "evaluator", envir = env)
+    get("mc_domains", envir = env)
+  } else {domains}
 
   # scenarios begin with the list of domains
   scenarios <- domains
 
   # attach each sheet as a nested dataframe to the domains object
   scenarios$raw_data <- scenarios$domain_id %>%
-    purrr::map(~ readxl::read_excel(survey_file, skip = 1, sheet = .x))
+    purrr::map(~ readxl::read_excel(
+      survey_file, skip = 2, col_names = c("Name", "DIFF", "Evidence",
+                                           "CapabilityID", letters[5:7]),
+      sheet = .))
 
   # separate out the threats from the nested frame
   scenarios$threats <- scenarios$raw_data %>%
@@ -84,7 +96,7 @@ import_scenarios <- function(survey_file = system.file("survey",
   dplyr::select(scenarios, scenario_id = "ScenarioID", scenario = "Scenario",
          tcomm = "TComm", tef = "TEF", tc = "TC", lm = "LM",
          domain_id = "domain_id", controls = "Capabilities") %>%
-    dplyr::mutate_at(vars("tef", "lm", "tc"), dplyr::funs(tolower)) %>%
+    dplyr::mutate_at(vars("tef", "lm", "tc"), tolower) %>%
     dplyr::arrange(.data$scenario_id)
 
 }
@@ -95,19 +107,36 @@ import_scenarios <- function(survey_file = system.file("survey",
 #' @importFrom readxl read_excel
 #' @importFrom purrr map
 #' @importFrom rlang .data
-#' @param survey_file Path to survey XLSX file. If not supplied, a default sample file is used.
+#' @inheritParams import_scenarios
+#' @param survey_file Path to survey Excel file. If not supplied, a default sample file is used.
 #' @param domains Dataframe of domains and domain IDs.
+#'
 #' @export
 #' @return Extracted capabilities as a dataframe.
 #' @examples
-#' data(domains)
-#' import_capabilities(domains = domains)
-import_capabilities <- function(survey_file = system.file("survey", "survey.xlsx", package = "evaluator"),
-                               domains){
+#' data(mc_domains)
+#' import_capabilities(domains = mc_domains)
+import_capabilities <- function(survey_file = NULL, domains = NULL){
+
+  survey_file <- if (is.null(survey_file)) {
+    system.file("survey", "survey.xlsx", package = "evaluator")
+    } else {
+      survey_file
+    }
+  if (!file.exists(survey_file)) {
+    stop("Non existant survey file specified - ", survey_file)}
+
+  # use default domains if none supplied
+  domains <- if (is.null(domains)) {
+    env <- new.env()
+    utils::data("mc_domains", package = "evaluator", envir = env)
+    get("mc_domains", env)
+  } else {domains}
 
   raw_domains <- domains %>%
     dplyr::mutate(raw_data = purrr::map(.data$domain_id, ~ readxl::read_excel(
-      survey_file, skip=1, sheet=.)))
+      survey_file, skip = 2,
+      col_names = c("Name", "DIFF", "Evidence", "CapabilityID", letters[5:7]), sheet = .)))
 
   ## ----walk_the_frame------------------------------------------------------
   dat <- raw_domains %>%
@@ -127,12 +156,12 @@ import_capabilities <- function(survey_file = system.file("survey", "survey.xlsx
 #'
 #' The default data collection Excel spreadsheet solicits threat
 #'   scenarios and applicable controls for each domain. This function
-#'   takes a single sheet from the spreadsheet, as read by \code{\link[readxl]{readxl}}
+#'   takes a single sheet from the spreadsheet, as read by \code{\link[readxl]{read_excel}}
 #'   and pulls out either the capabilities or threats, as directed by the
 #'   user.
 #'
-#' @importFrom dplyr %>% select
-#' @param dat Raw sheet input from \code{\link[readxl]{readxl}}.
+#' @importFrom dplyr select
+#' @param dat Raw sheet input from \code{\link[readxl]{read_excel}}.
 #' @param table_type Either \code{capabilities} or \code{threats}
 #' @return Extracted table as a dataframe
 split_sheet <- function(dat, table_type = "capabilities") {
