@@ -1,4 +1,4 @@
-context("openfair-example")
+context("OpenFAIR Example Shiny app")
 
 library(shinytest)
 
@@ -6,13 +6,17 @@ test_that("openfairExample() works", {
   # Don't run these tests on the CRAN build servers
   skip_on_cran()
 
-  # Not quite ready to turn this on in CI
-  skip_on_appveyor()
-  skip_on_travis()
+  skip_if_not(rmarkdown::pandoc_available(),
+              message = "Cannot run shinytest without pandoc available.")
+
+  # Don't run on r-devel, which behaves badly on TravisCI
+  skip_if(grepl("unstable", R.version.string),
+          message = "Shinytest gives unpredictable results on R-devel")
 
   # Use compareImages=FALSE because the expected image screenshots were created
   # on a Mac, and they will differ from screenshots taken on the CI platform,
   # which runs on Linux.
   appdir <- system.file(package = "evaluator", "openfair_example")
+
   expect_pass(testApp(appdir, compareImages = FALSE))
 })
